@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 
 """
+
+## From Version 0.9.12 the master repository for _dnslib_ has been moved to GitHub (https://github.com/paulc/dnslib). Please update any links to the original BitBucket repository as this will no longer be maintained.
+
+
 dnslib
 ------
 
@@ -271,7 +275,7 @@ To send a DNSSEC request (EDNS OPT record with DO flag & header AD flag):
     ; EDNS: version: 0, flags: do; udp: 4096
 
 The library also includes a simple framework for generating custom DNS
-resolvers in dnslib.server (see module docs). In post cases this just 
+resolvers in dnslib.server (see module docs). In most cases this just 
 requires implementing a custom 'resolve' method which receives a question 
 object and returns a response.
 
@@ -312,7 +316,7 @@ Changelog:
  *   0.8.1   2012-11-05  Added NAPTR test case and fixed logic error
                          Patch provided by Stefan Andersson (https://bitbucket.org/norox) - thanks
  *   0.8.2   2012-11-11  Patch to fix IPv6 formatting
-                         Patch provided by Torbjörn Lönnemark (https://bitbucket.org/tobbezz) - thanks
+                         Patch provided by Torbjorn Lonnemark (https://bitbucket.org/tobbezz) - thanks
  *   0.8.3   2013-04-27  Don't parse rdata if rdlength is 0
                          Patch provided by Wesley Shields <wxs@FreeBSD.org> - thanks
  *   0.9.0   2014-05-05  Major update including Py3 support (see docs)
@@ -341,6 +345,11 @@ Changelog:
                          Quote/unquote non-printable characters in DNS labels
                          Update test data
                          (Thanks to <raul@dinosec.com> for help)
+ *   0.9.11  2019-12-17  Encode NOTIFY Opcode (Issue #26)
+ *   0.9.12  2019-12-17  Transition master repository to Github (Bitbucket shutting down hg)
+ *   0.9.13  2020-06-01  Handle truncated requests in server.py (Issue #9)
+                         Replace thred.isAlive with thread.is_alive (Deprecated in Py3.9)
+                         Merged Pull Request #4 (Extra options for intercept.py) - thanks to @nolanl
 
 License:
 --------
@@ -350,19 +359,20 @@ BSD
 Author:
 -------
 
- *   Paul Chakravarti (paul.chakravarti@gmail.com)
+ *   PaulC 
 
 Master Repository/Issues:
 -------------------------
 
- *   https://bitbucket.org/paulc/dnslib
-     (Cloned on GitHub: https://github.com/paulchakravarti/dnslib)
+ *   https://github.com/paulc/dnslib  
+
+ (Note: https://bitbucket.org/paulc/dnslib has been deprecated and will not be updated)
 
 """
 
 from dnslib.dns import *
 
-version = "0.9.10"
+version = "0.9.13"
 
 if __name__ == '__main__':
     import doctest,textwrap
